package com.ruoyi.web.controller.business;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.UsageRecord;
import com.ruoyi.system.service.IUsageRecordService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 使用记录Controller
 * 
 * @author boman
 * @date 2022-06-13
 */
@RestController
@RequestMapping("/system/record")
public class UsageRecordController extends BaseController
{
    @Autowired
    private IUsageRecordService usageRecordService;

    /**
     * 查询使用记录列表
     */
    @PreAuthorize("@ss.hasPermi('system:record:list')")
    @GetMapping("/list")
    public TableDataInfo list(UsageRecord usageRecord)
    {
        startPage();
        List<UsageRecord> list = usageRecordService.selectUsageRecordList(usageRecord);
        return getDataTable(list);
    }

    /**
     * 导出使用记录列表
     */
    @PreAuthorize("@ss.hasPermi('system:record:export')")
    @Log(title = "使用记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, UsageRecord usageRecord)
    {
        List<UsageRecord> list = usageRecordService.selectUsageRecordList(usageRecord);
        ExcelUtil<UsageRecord> util = new ExcelUtil<UsageRecord>(UsageRecord.class);
        util.exportExcel(response, list, "使用记录数据");
    }

    /**
     * 获取使用记录详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:record:query')")
    @GetMapping(value = "/{recordId}")
    public AjaxResult getInfo(@PathVariable("recordId") Long recordId)
    {
        return AjaxResult.success(usageRecordService.selectUsageRecordByRecordId(recordId));
    }

    /**
     * 新增使用记录
     */
    @PreAuthorize("@ss.hasPermi('system:record:add')")
    @Log(title = "使用记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody UsageRecord usageRecord)
    {
        return toAjax(usageRecordService.insertUsageRecord(usageRecord));
    }

    /**
     * 修改使用记录
     */
    @PreAuthorize("@ss.hasPermi('system:record:edit')")
    @Log(title = "使用记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody UsageRecord usageRecord)
    {
        return toAjax(usageRecordService.updateUsageRecord(usageRecord));
    }

    /**
     * 删除使用记录
     */
    @PreAuthorize("@ss.hasPermi('system:record:remove')")
    @Log(title = "使用记录", businessType = BusinessType.DELETE)
	@DeleteMapping("/{recordIds}")
    public AjaxResult remove(@PathVariable Long[] recordIds)
    {
        return toAjax(usageRecordService.deleteUsageRecordByRecordIds(recordIds));
    }
}
